==> apache-gluten-1.3.0-incubating-src.tar.gz: incubator-gluten-1.3.0/backends-clickhouse/src/main/scala/org/apache/gluten/vectorized/NativeExpressionEvaluator.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.gluten.vectorized

import org.apache.gluten.backendsapi.clickhouse.CHConf
import org.apache.gluten.utils.ConfigUtil

import scala.collection.JavaConverters._

// TODO: move CHNativeExpressionEvaluator to NativeExpressionEvaluator
/** Scala Wrapper for ExpressionEvaluatorJniWrapper */
object NativeExpressionEvaluator {

  def updateQueryRuntimeSettings(settings: Map[String, String]): Unit = {
    ExpressionEvaluatorJniWrapper.updateQueryRuntimeSettings(
      ConfigUtil.serialize(
        settings
          .filter(t => CHConf.startWithSettingsPrefix(t._1) && t._2.nonEmpty)
          .map {
            case (k, v) =>
              (CHConf.removeSettingsPrefix(k), v)
          }
          .asJava))
  }
}

==> apache-gluten-1.5.0-incubating-src.tar.gz: incubator-gluten-1.5.0/backends-clickhouse/src/main/scala/org/apache/gluten/vectorized/NativeExpressionEvaluator.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.gluten.vectorized

import org.apache.gluten.backendsapi.clickhouse.CHConfig
import org.apache.gluten.utils.ConfigUtil

import scala.collection.JavaConverters._

// TODO: move CHNativeExpressionEvaluator to NativeExpressionEvaluator
/** Scala Wrapper for ExpressionEvaluatorJniWrapper */
object NativeExpressionEvaluator {

  def updateQueryRuntimeSettings(settings: Map[String, String]): Unit = {
    ExpressionEvaluatorJniWrapper.updateQueryRuntimeSettings(
      ConfigUtil.serialize(
        settings
          .filter(t => CHConfig.startWithSettingsPrefix(t._1) && t._2.nonEmpty)
          .map {
            case (k, v) =>
              (CHConfig.removeSettingsPrefix(k), v)
          }
          .asJava))
  }
}
